Struct style::values::generics::effects::SimpleShadow
[−]
[src]
pub struct SimpleShadow<Color, SizeLength, ShapeLength> {
pub color: Color,
pub horizontal: SizeLength,
pub vertical: SizeLength,
pub blur: ShapeLength,
}A generic value for the drop-shadow() filter and the text-shadow property.
Contrary to the canonical order from the spec, the color is serialised first, like in Gecko and Webkit.
Fields
color: Color
Color.
horizontal: SizeLength
Horizontal radius.
vertical: SizeLength
Vertical radius.
blur: ShapeLength
Blur radius.